==> haskell-regex-compat-tdfa-0.95.1.4-224-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-compat-tdfa
version:              0.95.1.4
visibility:           public
id:                   regex-compat-tdfa-0.95.1.4-FGLuoCnMXSA9274GtjDkXa
key:                  regex-compat-tdfa-0.95.1.4-FGLuoCnMXSA9274GtjDkXa
license:              BSD-3-Clause
copyright:
    Copyright (c) Christopher Kuklewicz 2006
    (c) shelarcy 2012

maintainer:           shelarcy <shelarcy@gmail.com>
author:               Christopher Kuklewicz
stability:            Seems to work, passes a few tests
homepage:             http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url:          http://hackage.haskell.org/package/regex-compat-tdfa
synopsis:             Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.

    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.

    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.

category:             Text
abi:                  db849fcac0dbb961947c5c8f11527e25
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/regex-compat-tdfa-0.95.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat-tdfa
hs-libraries:         HSregex-compat-tdfa-0.95.1.4-FGLuoCnMXSA9274GtjDkXa
depends:
    array-0.5.4.0 base-4.16.4.0
    regex-base-0.94.0.3-5QkTUG2Rv2vEZRXRGODVzk
    regex-tdfa-1.3.2.2-6AnOm16VvTN1aosgtNckO2

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-tdfa-0.95.1.4-225-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-compat-tdfa
version:              0.95.1.4
visibility:           public
id:                   regex-compat-tdfa-0.95.1.4-LNN5kmHMjjO4xJwgsffrAN
key:                  regex-compat-tdfa-0.95.1.4-LNN5kmHMjjO4xJwgsffrAN
license:              BSD-3-Clause
copyright:
    Copyright (c) Christopher Kuklewicz 2006
    (c) shelarcy 2012

maintainer:           shelarcy <shelarcy@gmail.com>
author:               Christopher Kuklewicz
stability:            Seems to work, passes a few tests
homepage:             http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url:          http://hackage.haskell.org/package/regex-compat-tdfa
synopsis:             Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.

    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.

    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.

category:             Text
abi:                  43c1c7d68fb60e9a60c5d6de5351aab0
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/regex-compat-tdfa-0.95.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat-tdfa
hs-libraries:         HSregex-compat-tdfa-0.95.1.4-LNN5kmHMjjO4xJwgsffrAN
depends:
    array-0.5.4.0 base-4.16.4.0
    regex-base-0.94.0.3-5QkTUG2Rv2vEZRXRGODVzk
    regex-tdfa-1.3.2.2-F5WIJphxps6tkovtNlc0r

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
